// 提供数据同步服务，确保本地数据与云端保持一致
import Taro from '@tarojs/taro'
import { type Room } from '@/types/room'

// 数据同步服务
export const syncService = {
  // 同步房间到云端
  async syncRoom(room: Room) {
    if (process.env.TARO_ENV !== 'weapp' || !Taro.cloud) {
      return false
    }
    
    try {
      const db = Taro.cloud.database()
      const roomCollection = db.collection('rooms')
      
      // 检查房间是否已存在
      const { data } = await roomCollection.where({
        id: room.id
      }).get()
      
      if (data && data.length > 0 && data[0]._id) {
        // 确保_id存在并转换为字符串
        const docId = data[0]._id.toString()
        
        // 更新已有房间
        await roomCollection.doc(docId).update({
          data: room
        })
      } else {
        // 创建新房间
        await roomCollection.add({
          data: room
        })
      }
      
      return true
    } catch (error) {
      console.error('同步房间失败:', error)
      return false
    }
  },
  
  // 其他同步方法...
}