//管理导航栏状态和导航逻辑
import { defineStore } from 'pinia'
import Taro from '@tarojs/taro'

// TabBar 项目的接口定义
export interface TabBarItem {
  pagePath: string
  text: string
  icon: any
}

export const useTabBarStore = defineStore('tabbar', {
  state: () => ({
    currentIndex: 0,
    switching: false,
    tabList: [
      {
        pagePath: '/pages/index/index',
        text: '游戏广场',
        icon: 'Home'
      },
      {
        pagePath: '/pages/room/join/index',
        text: '房间',
        icon: 'Find'
      },
      {
        pagePath: '/pages/history/index',
        text: '历史记录',
        icon: 'Clock'
      },
      {
        pagePath: '/pages/profile/index',
        text: '我的',
        icon: 'My'
      }
    ]
  }),
  
  actions: {
    // 更新当前选中的 tab
    updateSelected() {
      const pages = Taro.getCurrentPages()
      if (!pages || pages.length === 0) return
      
      const currentPage = pages[pages.length - 1]
      if (!currentPage || !currentPage.route) return
      
      const url = `/${currentPage.route}`
      console.log('当前页面路径:', url)
      
      // 查找当前页面在哪个 tab
      const index = this.tabList.findIndex(item => item.pagePath === url)
      
      // 只有确实匹配到 tab 时才更新状态
      if (index !== -1) {
        console.log('更新选中 tab 为:', index)
        this.currentIndex = index
      } else {
        console.log('当前页面不在 tab 列表中:', url)
      }
    },
    
    // 切换 tab
    switchTab(url: string, index: number) {
      if (this.switching) return // 防止重复点击
      
      console.log('尝试切换到:', url, index)
      this.switching = true
      
      // 先更新 UI 状态
      this.currentIndex = index
      
      // 执行页面跳转
      Taro.reLaunch({
        url,
        success: () => {
          console.log('跳转成功到:', url)
          this.currentIndex = index
        },
        fail: (error) => {
          console.error('跳转失败:', error)
        },
        complete: () => {
          this.switching = false
        }
      })
    },
    
    // 在应用启动时初始化监听
    setupListeners() {
      // 绑定页面显示事件
      Taro.eventCenter.on('taroPageShow', this.updateSelected.bind(this))
      
      // 绑定路由变化事件
      Taro.eventCenter.on('routeChange', this.updateSelected.bind(this))
      
      // 监听小程序显示事件
      Taro.onAppShow(this.updateSelected.bind(this))
    },
    
    // 移除监听
    removeListeners() {
      Taro.eventCenter.off('taroPageShow', this.updateSelected.bind(this))
      Taro.eventCenter.off('routeChange', this.updateSelected.bind(this))
      Taro.offAppShow(this.updateSelected.bind(this))
    }
  }
}) 