// types/games/werewolf.ts
// 玩家角色类型
export type WerewolfRole = 
  | 'werewolf'     // 狼人
  | 'villager'     // 村民
  | 'seer'         // 预言家
  | 'witch'        // 女巫
  | 'hunter'       // 猎人
  | 'guard'        // 守卫
  | 'idiot'        // 白痴
  | 'elder'        // 长老
  | 'cupid'        // 丘比特
  | 'thief'        // 盗贼
  | 'moderator';   // 主持人/上帝

// 游戏阶段
export type GamePhase =
  | 'waiting'      // 等待开始
  | 'night'        // 夜晚
  | 'day'          // 白天
  | 'vote'         // 投票
  | 'ended';       // 游戏结束

// 行动类型
export type ActionType = 
  | 'kill'         // 狼人杀人
  | 'check'        // 预言家查验
  | 'save'         // 女巫救人
  | 'poison'       // 女巫毒人
  | 'protect'      // 守卫保护
  | 'shoot'        // 猎人开枪
  | 'vote'         // 投票
  | 'pair';        // 丘比特连线

// 玩家状态
export type PlayerStatus = 
  | 'alive'        // 存活
  | 'dead'         // 死亡
  | 'protected'    // 受保护
  | 'poisoned'     // 中毒
  | 'coupled';     // 情侣

// 游戏结果类型
export type GameResult = 
  | 'werewolf_win'  // 狼人阵营胜利
  | 'villager_win'  // 村民阵营胜利
  | 'couple_win'    // 情侣胜利
  | 'draw'          // 平局
  | null;           // 游戏进行中

// 玩家信息
export interface WerewolfPlayer {
  id: string;
  name: string;
  avatar: string;
  role: WerewolfRole;
  status: PlayerStatus;
  isReady: boolean;
  isDead: boolean;
  actions: {
    [key in ActionType]?: boolean;
  };
  // 特殊状态
  isLovers?: boolean;      // 是否为情侣
  lastWords?: string;      // 遗言
  voteTarget?: string;     // 投票目标
  deadRound?: number;      // 死亡回合
}

// 游戏日志
export interface GameLog {
  round: number;
  phase: GamePhase;
  content: string;
  timestamp: number;
  isPublic: boolean;
  targetPlayers?: string[];
}

// 游戏状态
export interface WerewolfGame {
  id: string;
  title: string;
  hosterId: string;
  hosterName: string;
  createTime: number;
  startTime: number | null;
  endTime: number | null;
  players: WerewolfPlayer[];
  currentRound: number;
  phase: GamePhase;
  result: GameResult;
  currentAction: ActionType | null;
  timeLimit: number;      // 每个阶段的时间限制(秒)
  logs: GameLog[];
  options: {
    roles: {
      [key in WerewolfRole]?: number; // 角色数量配置
    };
    includeSpecialRoles: boolean; // 是否包含特殊角色
    allowLastWords: boolean;      // 是否允许遗言
    nightTimeLimit: number;       // 夜晚时间限制
    dayTimeLimit: number;         // 白天时间限制
    voteTimeLimit: number;        // 投票时间限制
  };
}